import { __decorate } from "tslib";
import { bodyFont } from '@microsoft/fast-components';
import { attr, customElement, DOM, FASTElement, observable } from '@microsoft/fast-element';
import { defaultBodyFont, EventName } from '../../types';
import { logger } from '../../utils';
import { applyStyleChanges } from '../../utils/utils';
import { PreviewComponentsStyles as styles } from './preview-components.styles';
import { PreviewComponentsTemplate as template } from './preview-components.template';
let PreviewComponents = class PreviewComponents extends FASTElement {
    constructor() {
        super(...arguments);
        this.prefix = 'zero';
        this.buttonAppearanceAccent = 'primary-blue';
        this.buttonAppearanceNeutral = 'primary-grey';
        this.buttonAppearanceOutline = 'primary-gradient';
        this.buttonAppearanceText = 'lightweight';
        this.badgeAppearanceAccent = 'primary';
        this.badgeAppearanceNeutral = 'secondary';
        this.badgeText = 'white';
        this.cards = Array.from({ length: 8 }, (_, i) => i + 1);
        this.countries = [
            'Afghanistan',
            'Aland Islands',
            'Albania',
            'Algeria',
            'American Samoa',
            'Andorra',
            'Angola',
            'Aruba',
            'Australia',
            'Austria',
            'Azerbaijan',
            'Bahamas',
            'Bahrain',
            'Bangladesh',
            'Barbados',
            'Belarus',
            'Belgium',
            'Belize',
            'Benin',
            'Bhutan',
            'Bolivia',
            'Bonaire, Sint Eustatius and Saba',
            'Cambodia',
            'Cameroon',
            'Canada',
        ];
        this.menuActions = [
            {
                name: 'View',
                callback: (rowData) => logger.debug('VIEWW!!!', rowData),
            },
            {
                name: 'Delete',
                callback: (rowData) => logger.debug('DELETE!!!', rowData),
            },
            {
                name: 'Edit',
                callback: (rowData) => logger.debug('EDIT!!!', rowData),
            },
            {
                name: 'Wait',
                callback: (rowData) => logger.debug('WAIT???', rowData),
            },
        ];
        this.menuDefinition = {
            actions: this.menuActions,
            buttonAppearance: 'stealth',
            data: { name: 'test' },
        };
        this.dropDownMenuItems = [
            {
                name: 'Menu item 1',
                callback: () => alert('Menu item 1 clicked'),
                icon: {
                    name: 'glasses',
                },
            },
            {
                name: 'Menu item 2',
                callback: () => alert('Menu item 2 clicked'),
            },
            {
                name: 'Menu item 3',
                callback: () => alert('Menu item 3 clicked'),
                submenu: [
                    {
                        name: 'Menu item 5',
                        callback: () => alert('Menu item 5 clicked'),
                        icon: {
                            name: 'address-card',
                        },
                    },
                    {
                        name: 'Menu item 6',
                        callback: () => alert('Menu item 6 clicked'),
                        submenu: [
                            {
                                name: 'Menu item 7',
                                callback: () => alert('Menu item 7 clicked'),
                                color: 'red',
                                icon: {
                                    name: 'address-card',
                                },
                            },
                            {
                                name: 'Menu item 8',
                                callback: () => alert('Menu item 8 clicked'),
                                isDisabled: () => true,
                            },
                        ],
                    },
                ],
            },
        ];
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            this.handleStyleChanges(e);
        });
        document.body.addEventListener(EventName.DS_CHANGED, (e) => {
            this.handleDSChanges(e);
        });
        DOM.queueUpdate(() => {
            bodyFont.withDefault(defaultBodyFont);
        });
    }
    handleStyleChanges(e) {
        const detail = e.detail;
        if (detail) {
            DOM.queueUpdate(() => {
                applyStyleChanges(detail, this.provider);
            });
        }
    }
    handleDSChanges(event) {
        this.prefix = event.detail.prefix;
        this.buttonAppearanceAccent = event.detail.buttonAppearanceAccent;
        this.buttonAppearanceNeutral = event.detail.buttonAppearanceNeutral;
        this.buttonAppearanceOutline = event.detail.buttonAppearanceOutline;
        this.buttonAppearanceText = event.detail.buttonAppearanceText;
        this.badgeAppearanceAccent = event.detail.badgeAppearanceAccent;
        this.badgeAppearanceNeutral = event.detail.badgeAppearanceNeutral;
        this.badgeText = event.detail.badgeText;
    }
    showDialog(param) {
        this[param].show();
    }
    closeDialog(param) {
        this[param].close();
    }
    dismissBanner() {
        this.banner.dismiss();
    }
};
__decorate([
    observable
], PreviewComponents.prototype, "modal", void 0);
__decorate([
    attr
], PreviewComponents.prototype, "prefix", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "buttonAppearanceAccent", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "buttonAppearanceNeutral", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "buttonAppearanceOutline", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "buttonAppearanceText", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "badgeAppearanceAccent", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "badgeAppearanceNeutral", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "badgeText", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "cards", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "countries", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "menuActions", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "menuDefinition", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "dropDownMenuItems", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "provider", void 0);
PreviewComponents = __decorate([
    customElement({
        name: 'preview-components',
        template,
        styles,
    })
], PreviewComponents);
export { PreviewComponents };
